@@ -3,6 +3,7 @@ Map is a generic Map class from which all other Map classes inherit from.
 """
 import copy
 import html
+import numbers
 import textwrap
 import warnings
 import webbrowser
@@ -40,6 +41,7 @@ from sunpy.util.decorators import cached_property_based_on, deprecated
 from sunpy.util.exceptions import SunpyDeprecationWarning, SunpyMetadataWarning, SunpyUserWarning
 from sunpy.util.functools import seconddispatch
 from sunpy.visualization import axis_labels_from_ctype, peek_show, wcsaxes_compat
+from sunpy.visualization.colormaps import cm as sunpy_cm
 
 TIME_FORMAT = config.get("general", "time_format")
 PixelPair = namedtuple('PixelPair', 'x y')
@@ -222,6 +224,16 @@ class GenericMap(NDData):
         if plot_settings:
             self.plot_settings.update(plot_settings)
 
+        # Try and set the colormap. This is not always possible if this method
+        # is run before map sources fix some of their metadata, so
+        # just ignore any exceptions raised.
+        try:
+            cmap = self._get_cmap_name()
+            if cmap in sunpy_cm.cmlist:
+                self.plot_settings['cmap'] = cmap
+        except Exception:
+            pass
+
     def __getitem__(self, key):
         """ This should allow indexing by physical coordinate """
         raise NotImplementedError(
@@ -1450,6 +1462,12 @@ class GenericMap(NDData):
         pad_x = int(np.max((diff[1], 0)))
         pad_y = int(np.max((diff[0], 0)))
 
+        if issubclass(self.data.dtype.type, numbers.Integral) and (missing % 1 != 0):
+            warnings.warn(
+                "The specified `missing` value is not an integer, but the data "
+                "array is of integer type, so the output may be strange.",
+                SunpyUserWarning)
+
         new_data = np.pad(self.data,
                           ((pad_y, pad_y), (pad_x, pad_x)),
                           mode='constant',
@@ -2015,7 +2033,7 @@ class GenericMap(NDData):
                   'fill': False}
         kwergs.update(kwargs)
         rect = plt.Rectangle(bottom_left, width, height, **kwergs)
-        axes.add_artist(rect)
+        axes.add_patch(rect)
         return [rect]
 
     @u.quantity_input
